==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-quicklaunch/translations/quicklaunch_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="229"/>
        <source>Drop Error</source>
        <translation>Errore di rilascio</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="230"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Il file/URL &apos;%1&apos; in questo momento non può essere inserito in Avvio rapido</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="336"/>
        <source>Drop application
icons here</source>
        <translation>Rilascia qui le icone
delle applicazioni</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + trascina)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Sposta a sinistra</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Sposta a destra</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="64"/>
        <source>Remove from quicklaunch</source>
        <translation>Rimuovi da Avvio rapido</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-quicklaunch/translations/quicklaunch_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="229"/>
        <source>Drop Error</source>
        <translation>Errore di rilascio</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="230"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Il file/URL &apos;%1&apos; al momento non può essere inserito in Avvio rapido</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="336"/>
        <source>Drop application
icons here</source>
        <translation>Trascina qui le icone
delle applicazioni</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + trascina)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Sposta a sinistra</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Sposta a destra</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Rimuovi da Avvio rapido</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation>Ricarica</translation>
    </message>
</context>
</TS>
